<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-ro',
'0_langue' => 'Rom&acirc;n&#259; [ro]',
'0_liste' => 'spip-ro@rezo.net',
'0_mainteneur' => 'vmurariu@gmail.com',

// A
'access_interface_graphique' => '&Icirc;ntoarcere la interfa&#355;a grafic&#259; complet&#259;',
'access_mode_texte' => 'Afi&#351;a&#355;i interfa&#355;a textual&#259; simpl&#259;',
'admin_debug' => 'depanare',
'admin_modifier_article' => 'Modifica&#355;i articolul',
'admin_modifier_auteur' => 'Modifica&#355;i autorul',
'admin_modifier_breve' => 'Modifica&#355;i &#351;tirea',
'admin_modifier_mot' => 'Modifica&#355;i cuvântul cheie',
'admin_modifier_rubrique' => 'Modifica&#355;i rubrica',
'admin_recalculer' => 'Recalcula&#355;i aceast&#259; pagin&#259;',
'afficher_trad' => 'afi&#351;a&#355;i traducerile',
'alerte_maj_impossible' => '<b>Alert&#259;&nbsp;!</b> Aducerea la zi a bazei de date SQL c&#259;tre versiunea @version@ este imposibil&#259;, probabil din cauza unei probleme de drepturi de modificare &icirc;n baza de date. V&#259; rug&#259;m s&#259; contacta&#355;i furnizorul dumneavoastr&#259; de hosting.',
'alerte_modif_info_concourante' => 'ATEN&#354;IE : Aceast&#259; informa&#355;ie a fost modificat&#259;. Valoarea curent&#259; este&nbsp;:',
'analyse_xml' => 'Analiz&#259; XML',
'annuler' => 'Anula&#355;i',
'antispam_champ_vide' => 'V&#259; rug&#259;m s&#259; l&#259;sa&#355;i acest c&acirc;mp gol&nbsp;:',
'articles_recents' => 'Cele mai recente articole',
'avis_archive_incorrect' => 'fi&#351;ierul arhiv&#259; nu este de tip SPIP',
'avis_archive_invalide' => 'fi&#351;ierul arhiv&#259; nu este valid',
'avis_attention' => 'Aten&#355;ie!',
'avis_champ_incorrect_type_objet' => 'Numele de c&acirc;mp @name@ este incorect pentru obiecte de tip @type@ ',
'avis_colonne_inexistante' => 'Coloana @col@ nu exist&#259;',
'avis_echec_syndication_01' => 'Sindicalizarea a e&#351;uat: backend-ul indicat este indescifrabil sau nu propune nici un articol.',
'avis_echec_syndication_02' => 'Sindicalizarea a e&#351;uat: imposibil de accesat backend-ul acestui site.',
'avis_erreur' => 'Eroare: vede&#355;i mai jos',
'avis_erreur_connexion' => 'Eroare de conexiune',
'avis_erreur_cookie' => 'problem&#259; de cookie',
'avis_erreur_fonction_contexte' => 'Eroare de programare. Aceast&#259; func&#355;ie nu trebuie chemat&#259; &icirc;n acest context.',
'avis_erreur_mysql' => 'Eroare SQL',
'avis_erreur_sauvegarde' => 'Eroare &icirc;n timpul salv&#259;rii (@type@ @id_objet@) !',
'avis_erreur_visiteur' => 'Problem&#259; de acces &icirc;n sec&#355;iunea privat&#259;',

// B
'barre_a_accent_grave' => 'Insera&#355;i un A majuscul cu accent grav',
'barre_aide' => 'Utiliza&#355;i secven&#539;ele tipografice pentru a &icirc;mbog&#259;&#355;i aranjarea &icirc;n pagin&#259;',
'barre_e_accent_aigu' => 'Insera&#355;i un E majuscul cu accent ascu&#355;it',
'barre_eo' => 'Insera&#355;i un E &icirc;n O',
'barre_eo_maj' => 'Insera&#355;i un E &icirc;n O majuscul',
'barre_euro' => 'Insera&#355;i simbolul &euro;',
'barre_gras' => 'Transforma&#355;i &icirc;n litere {{aldine}} (&icirc;ngro&#351;ate)',
'barre_guillemets' => '&Icirc;nconjura&#355;i cu &laquo; ghilimele &raquo;',
'barre_guillemets_simples' => '&Icirc;nconjura&#355;i cu “ghilimele de nivel secund”',
'barre_intertitre' => 'Transforma&#355;i &icirc;n {{{inter-titlu}}}',
'barre_italic' => 'Transforma&#355;i &icirc;n litere {{italice}} (&icirc;nclinate)',
'barre_lien' => 'Transforma&#355;i &icirc;n [leg&#259;tur&#259; hipertext->http://...]',
'barre_lien_input' => 'V&#259; rug&#259;m s&#259; indica&#355;i adresa leg&#259;turii dumneavoastr&#259; (pute&#355;i indica o adres&#259; de Web sub forma http://www.situlmeu.ro sau chiar numai num&#259;rul unui articol de pe acest site).',
'barre_note' => 'Transforma&#355;i &icirc;n [[Not&#259; &icirc;n josul paginii]]',
'barre_paragraphe' => 'Crea&#355;i un paragraf',
'barre_quote' => '<quote>Cita&#355;i un mesaj</quote>',
'bouton_ajouter_document' => 'Adauga&#355;i un document',
'bouton_ajouter_image' => 'Ad&#259;uga&#355;i o imagine',
'bouton_ajouter_image_document' => 'Ad&#259;uga&#355;i o imagine sau un document',
'bouton_changer' => 'Schimba&#355;i',
'bouton_chercher' => 'C&#259;uta&#355;i',
'bouton_choisir' => 'Alege&#355;i',
'bouton_download' => 'Desc&#259;rca&#355;i',
'bouton_enregistrer' => '&Icirc;nregistra&#355;i',
'bouton_radio_desactiver_messagerie_interne' => 'Dezactiva&#355;i mesageria intern&#259;',
'bouton_radio_envoi_annonces' => 'Trimite&#355;i anun&#355;urile editoriale',
'bouton_radio_non_envoi_annonces' => 'Nu trimite&#355;i anun&#355;uri',
'bouton_radio_non_envoi_liste_nouveautes' => 'Nu trimite&#355;i lista de nout&#259;&#355;i',
'bouton_recharger_page' => 're-&icirc;nc&#259;rca&#539;i aceast&#259; pagin&#259;',
'bouton_telecharger' => 'Desc&#259;rca&#355;i',
'bouton_valider' => 'Valida&#355;i',

// C
'cal_apresmidi' => 'Dup&#259;-amiaz&#259;',
'cal_jour_entier' => 'toat&#259; ziua',
'cal_matin' => 'diminea&#355;a',
'cal_par_jour' => 'calendar pe zi',
'cal_par_mois' => 'calendar pe lun&#259;',
'cal_par_semaine' => 'calendar pe s&#259;pt&#259;m&acirc;n&#259;',
'choix_couleur_interface' => 'culoare',
'choix_interface' => 'alegerea interfe&#355;ei',
'colonne' => 'Coloan&#259;',
'confirm_changer_statut' => 'Aten&#355;ie, a&#355;i cerut schimbarea st&#259;rii acestui element. Dori&#355;i s&#259; continua&#355;i ?',
'correcte' => 'corect&#259;',

// D
'date_aujourdhui' => 'ast&#259;zi',
'date_avant_jc' => '&icirc;naintea erei noastre',
'date_dans' => '&icirc;n @delai@',
'date_de_mois_1' => '@j@ @nommois@',
'date_de_mois_10' => '@j@ @nommois@',
'date_de_mois_11' => '@j@ @nommois@',
'date_de_mois_12' => '@j@ @nommois@',
'date_de_mois_2' => '@j@ @nommois@',
'date_de_mois_3' => '@j@ @nommois@',
'date_de_mois_4' => '@j@ @nommois@',
'date_de_mois_5' => '@j@ @nommois@',
'date_de_mois_6' => '@j@ @nommois@',
'date_de_mois_7' => '@j@ @nommois@',
'date_de_mois_8' => '@j@ @nommois@',
'date_de_mois_9' => '@j@ @nommois@',
'date_demain' => 'm&acirc;ine',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ la @heure@',
'date_fmt_jour_mois' => '@jour@ @nommois@',
'date_fmt_jour_mois_annee' => '@jour@ @nommois@ @annee@',
'date_fmt_mois_annee' => '@nommois@ @annee@',
'date_fmt_nomjour_date' => '@nomjour@ @date@',
'date_heures' => 'ore',
'date_hier' => 'ieri',
'date_il_y_a' => 'acum @delai@',
'date_jnum1' => '1',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'Duminic&#259;',
'date_jour_1_abbr' => 'dum.',
'date_jour_1_initiale' => 'd.',
'date_jour_2' => 'Luni',
'date_jour_2_abbr' => 'lun.',
'date_jour_2_initiale' => 'l.',
'date_jour_3' => 'Mar&#355;i',
'date_jour_3_abbr' => 'mar.',
'date_jour_3_initiale' => 'ma.',
'date_jour_4' => 'Miercuri',
'date_jour_4_abbr' => 'mie.',
'date_jour_4_initiale' => 'mi.',
'date_jour_5' => 'Joi',
'date_jour_5_abbr' => 'joi',
'date_jour_5_initiale' => 'j.',
'date_jour_6' => 'Vineri',
'date_jour_6_abbr' => 'vin.',
'date_jour_6_initiale' => 'v.',
'date_jour_7' => 'S&acirc;mb&#259;t&#259;',
'date_jour_7_abbr' => 's&acirc;m.',
'date_jour_7_initiale' => 's.',
'date_jours' => 'zile',
'date_minutes' => 'minute',
'date_mois' => 'luni',
'date_mois_1' => 'ianuarie',
'date_mois_10' => 'octombrie',
'date_mois_11' => 'noiembrie',
'date_mois_12' => 'decembrie',
'date_mois_2' => 'februarie',
'date_mois_3' => 'martie',
'date_mois_4' => 'aprilie',
'date_mois_5' => 'mai',
'date_mois_6' => 'iunie',
'date_mois_7' => 'iulie',
'date_mois_8' => 'august',
'date_mois_9' => 'septembrie',
'date_saison_1' => 'iarna',
'date_saison_2' => 'prim&#259;vara',
'date_saison_3' => 'vara',
'date_saison_4' => 'toamna',
'date_secondes' => 'secunde',
'date_semaines' => 's&#259;pt&#259;m&acirc;ni',
'date_un_mois' => 'luna',
'date_une_heure' => 'ora',
'date_une_minute' => 'minut',
'date_une_seconde' => 'secunda',
'date_une_semaine' => 'saptamana',
'dirs_commencer' => ' pentru a &icirc;ncepe cu adev&#259;rat instalarea',
'dirs_preliminaire' => 'Preliminar : <b>Regla&#355;i drepturile de acces</b>',
'dirs_probleme_droits' => 'Problem&#259; de drepturi de acces',
'dirs_repertoires_absents' => '<p><b>Urm&#259;toarele directoare nu au fost g&#259;site&nbsp;:</b></p> <ul>@bad_dirs@.</ul>
  <p>Cel mai probabil, aceast&#259; situa&#355;ie este datorat&#259; unei probleme de litere majuscule sau minuscule.
 Verifica&#539;i ca litere majuscule &#351;i minuscule a acestor directoare s&#259; concorde cu ceea ce este afi&#351;at
 mai sus; dac&#259; nu este cazul, redenumi&#539;i directoarele cu ajutorul programului dumneavoastr&#259; favorit de FTP pentru a corecta eroarea.
  <p>Odat&#259; terminat&#259; aceast&#259; manipulare, pute&#539;i ',
'dirs_repertoires_suivants' => '<p><b>Directoarele urm&#259;toare nu sunt accesibile &icirc;n mod scriere&nbsp;:</b></p> <ul>@bad_dirs@.</ul>
  <p>Pentru a remedia aceast&#259; problem&#259;, utiliza&#355;i clientul dumneavoastr&#259; favorit de FTP pentru a modifica drepturile de acces ale fiec&#259;rui
  dintre aceste directoare. Procedura este explicat&#259; &icirc;n detaliu &icirc;n manualul de instalare.</p>
  <p>Odat&#259; terminat&#259; aceast&#259; manipulare, pute&#355;i ',
'double_occurrence' => 'Ocuren&#355;&#259; dubl&#259;', # MODIF

// E
'en_cours' => '&icirc;n curs',
'entree_dimensions' => 'Dimensiuni&nbsp;:',
'entree_titre_document' => 'Titlul documentului&nbsp;:',
'entree_titre_image' => 'Titlul imaginii&nbsp;:',
'envoi_via_le_site' => 'Trimitere via site',
'erreur' => 'Eroare',
'erreur_balise_non_fermee' => 'ultima baliz&#259; (tag) ne-&icirc;nchis&#259;:',
'erreur_texte' => 'eroare(i)',
'etape' => 'Etap&#259;',

// F
'fichier_introuvable' => 'Fi&#351;ier @fichier@ de neg&#259;sit',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => 'Sunte&#355;i deja &icirc;nscris.',
'form_email_non_valide' => 'Adresa dumneavoastr&#259; de email nu este valabil&#259;.',
'form_forum_access_refuse' => 'Nu mai ave&#355;i dreptul de acces la acest site.',
'form_forum_bonjour' => 'Bun? ziua @nom@,',
'form_forum_email_deja_enregistre' => 'Aceast&#259; adres&#259; de email este deja &icirc;nregistrat&#259;. Pute&#355;i, a&#351;adar, utiliza parola dumneavoastr&#259; obi&#351;nuit&#259;.',
'form_forum_identifiant_mail' => 'Noul dumneavoastr&#259; identificator tocmai v-a fost trimis pe email.',
'form_forum_identifiants' => 'Identificatori personali',
'form_forum_indiquer_nom_email' => 'Indica&#355;i aici numele &#537;i adresa dumneavoastra de email. Identificatorul dumneavoastr&#259; personal v&#259; va parveni &icirc;n scurt timp prin email.',
'form_forum_login' => 'login :',
'form_forum_message_auto' => '(acesta este un mesaj automatic)',
'form_forum_pass' => 'parola :',
'form_forum_probleme_mail' => 'Problem&#259; de email&nbsp;: identificatorul nu poate fi trimis.',
'form_forum_voici1' => 'Iat&#259; identificatorii dumneavoastr&#259; pentru a participa la activitatea
site-ului "@nom_site_spip@" (@adresse_site@) :',
'form_forum_voici2' => 'Iat&#259; identificatorii dvs. pentru a putea propune articole pe
site-ul "@nom_site_spip@" (@adresse_login@):',
'form_indiquer_email' => 'V&#259; rug&#259;m sa indica&#355;i adresa dumneavoastr&#259; de email.',
'form_indiquer_nom' => 'Va rug&#259;m s&#259; indica&#355;i numele dumneavoastr&#259;.',
'form_indiquer_nom_site' => 'V&#259; rug&#259;m s&#259; indica&#355;i adresa site-ul dumneavoastr&#259; de web.',
'form_pet_adresse_site' => 'Adresa site-ului dumneavoastr&#259;',
'form_pet_aucune_signature' => 'Nici o semn&#259;tur&#259; nu corespunde acestui cod...',
'form_pet_confirmation' => 'V&#259; rug&#259;m s&#259; confirma&#355;i semn&#259;tura dumneavoastr&#259; :',
'form_pet_deja_enregistre' => 'Acest site este deja &icirc;nregistrat',
'form_pet_deja_signe' => 'A&#355;i semnat deja acest text.',
'form_pet_envoi_mail_confirmation' => 'Un email de confirmare tocmai v-a fost trimis la adresa @email@. Pentru a valida semn&#259;tura dumneavoastr&#259;, va trebui s&#259; vizita&#355;i adresa de web men&#355;ionat&#259; in email.',
'form_pet_mail_confirmation' => 'Bun&#259; ziua,

A&#355;i cerut s&#259; semna&#355;i peti&#355;ia :
@titre@.

A&#355;i furnizat informa&#355;iile urm&#259;toare :
    Nume: @nom_email@
    Site: @nom_site@ - @url_site@


IMPORTANT...
Pentru a valida semn&#259;tura, trebuie s&#259; vizita&#355;i
adresa de mai jos (&icirc;n caz contrat, cererea dumneavoastr&#259; va fi refuzat&#259;) :

    @url@


Mul&#355;umim pentru participarea dumneavoastr&#259;
',
'form_pet_message_commentaire' => 'Un mesaj, un comentariu&nbsp;?',
'form_pet_nom_site2' => 'Numele site-ului dumneavoastr&#259; de Web',
'form_pet_probleme_liens' => 'V&#259; rug&#259;m s&#259; reluati introducerea mesajului - suprima&#355;i leg&#259;turile hipertext.',
'form_pet_probleme_technique' => 'Datorit&#259; unor probleme tehnice, semn&#259;turile sunt deocamdat&#259; suspendate.',
'form_pet_signature_pasprise' => 'Semn&#259;tura dumneavoastr&#259; nu a fost luat&#259; &icirc;n considerare.',
'form_pet_signature_validee' => 'Semn&#259;tura dumneavoastr&#259; este validat&#259;. Mul&#355;umiri &nbsp;!',
'form_pet_site_deja_enregistre' => 'Acest site este deja &icirc;nregistrat',
'form_pet_url_invalide' => 'Adresa URL indicat&#259; nu este valabil&#259;.',
'form_pet_votre_email' => 'Adresa dumneavoastr&#259; de email',
'form_pet_votre_nom' => 'Numele sau pseudonimul dumneavoastr&#259;',
'form_pet_votre_site' => 'Dac&#259; ave&#355;i un site Web, pute&#355;i s&#259;-l indica&#355;i mai jos',
'form_prop_confirmer_envoi' => 'Confirma&#355;i trimiterea',
'form_prop_description' => 'Descriere/comentariu',
'form_prop_enregistre' => 'Propunerea dumneavoastr&#259; a fost &icirc;nregistrat&#259;, ea va fi publicat&#259; dup&#259; validarea ei de c&#259;tre responsabilii acestui site.',
'form_prop_envoyer' => 'Trimite&#355;i un mesaj',
'form_prop_indiquer_email' => 'V&#259; rug&#259;m s&#259; indica&#355;i o adres&#259; de email valabil&#259;',
'form_prop_indiquer_nom_site' => 'Va rug&#259;m s&#259; indica&#355;i numele site-ului.',
'form_prop_indiquer_sujet' => 'Va rug&#259;m s&#259; indica&#355;i un subiect',
'form_prop_message_envoye' => 'Mesaj trimis',
'form_prop_nom_site' => 'Numele site-ului',
'form_prop_non_enregistre' => 'Propunerea dumneavoastr&#259; nu a fost &icirc;nregistrat&#259;.',
'form_prop_sujet' => 'Subiect',
'form_prop_url_site' => 'Adresa (URL-ul) site-ului',
'forum_acces_refuse' => 'Nu mai ave&#355;i acces la aceste forum-uri.',
'forum_attention_dix_caracteres' => '<b>Aten&#355;ie&nbsp;!</b> mesajul dumneavoastr&#259; trebuie s&#259; con&#355;in&#259; cel pu&#355;in  zece caractere.',
'forum_attention_trois_caracteres' => '<b>Aten&#355;ie&nbsp;!</b> titlul dumneavoastr&#259; trebuie s&#259; con&#355;in&#259; cel pu&#355;in trei caractere.',
'forum_attention_trop_caracteres' => '<b>Aten&#355;ie&nbsp;!</b> mesajul dumneavoastr&#259; este prea lung(@compte@ caractere)&nbsp;: pentru a-l putea &icirc;nregistra, mesajul nu trebuie s&#259; dep&#259;&#351;easc&#259; @max@ caractere.',
'forum_avez_selectionne' => 'A&#355;i selec&#355;ionat&nbsp;:',
'forum_cliquer_retour' => 'Face&#355;i click <a href=\'@retour_forum@\'>aici</a> pentru a continua.',
'forum_forum' => 'forum',
'forum_info_modere' => 'Acest forum este moderat: contribu&#355;ia dumneavoastr&#259; nu va apare dec&acirc;t dup&#259; ce va fi validat&#259; de c&#259;tre un administrator al site-ului.',
'forum_lien_hyper' => '<b>Leg&#259;tur&#259; hipertext</b> (op&#355;ional&#259;)',
'forum_message_definitif' => 'Mesaj definitiv : trimite&#355;i c&#259;tre site',
'forum_message_trop_long' => 'Mesajul dumneavoastr&#259; este prea lung. Pute&#539;i folosi maxim 20.000 caractere.',
'forum_ne_repondez_pas' => 'Nu r&#259;spunde&#355;i acestui email, ci direct pe forum la adresa urm&#259;toare :',
'forum_non_inscrit' => 'Nu sunte&#355;i &icirc;nscris, sau adresa ori parola dumneavoastr&#259; nu sunt corecte.',
'forum_page_url' => '(Dac&#259; mesajul se refer&#259; la un articol publicat pe Web sau la o pagin&#259; cu informa&#355;ii suplimentare, indica&#355;i mai jos titlul &#351;i adresa URL a paginii.)',
'forum_par_auteur' => 'de @auteur@',
'forum_poste_par' => 'Mesaj publicat de @parauteur@ ca r&#259;spuns la articolul &laquo; @titre@ &raquo;.',
'forum_probleme_database' => 'Problem&#259; tehnic&#259; cu baza de date, mesajul dumneavoastr&#259; nu a fost &icirc;nregistrat.',
'forum_qui_etes_vous' => '<b>Cine sunte&#355;i dumneavoastr&#259; ?</b> (op&#355;ional)',
'forum_texte' => 'Textul mesajului dumneavoastr&#259; :',
'forum_titre' => 'Titlu :',
'forum_titre_erreur' => 'Eroare...',
'forum_url' => 'URL :',
'forum_valider' => 'Valida&#355;i aceast&#259; alegere',
'forum_voir_avant' => 'Vede&#355;i acest mesaj &icirc;nainte de a-l trimite',
'forum_votre_email' => 'Adresa dumneavoastr&#259; de email :',
'forum_votre_nom' => 'Numele dumneavoastr&#259; (sau pseudonimul) :',
'forum_vous_enregistrer' => 'Pentru a participa
  la acest forum, trebuie s&#259; v&#259; &icirc;nregistra&#355;i &icirc;n prealabil. V&#259; rug&#259;m s&#259; furniza&#355;i identificatorul personal care v-a fost furnizat.
  Dac&#259; nu sunte&#355;i deja &icirc;nregistrat, va trebui',
'forum_vous_inscrire' => '&nbsp;s&#259; v&#259; &icirc;nscrie&#355;i.',

// I
'ical_texte_rss_articles' => 'Fi&#351;ierul &laquo;backend&raquo; al articolelor acestui site se g&#259;se&#351;te la adresa:',
'ical_texte_rss_articles2' => 'Pute&#355;i, de asemenea, ob&#355;ine fi&#351;ierele &laquo;backend&raquo; pentru articolele fiec&#259;rei rubrici de pe site:',
'ical_texte_rss_breves' => 'Exist&#259;, de asemenea, un fi&#351;ier con&#355;in&acirc;nd &#351;tirile acestui site. Preciz&acirc;nd num&#259;rul rubricii, ve&#355;i ob&#355;ine doar &#351;tirile acelei rubrici.',
'icone_a_suivre' => 'Prima pagin&#259;',
'icone_admin_site' => 'Administrarea site-ului',
'icone_agenda' => 'Agenda',
'icone_aide_ligne' => 'Ajutor',
'icone_articles' => 'Articole',
'icone_auteurs' => 'Autori',
'icone_breves' => '&#350;tiri',
'icone_brouteur' => 'Navigare rapid&#259;',
'icone_configuration_site' => 'Configurare',
'icone_configurer_site' => 'Configura&#355;i-v&#259; site-ul',
'icone_creer_nouvel_auteur' => 'Crea&#355;i un nou autor',
'icone_creer_rubrique' => 'Crea&#355;i o rubric&#259;',
'icone_creer_sous_rubrique' => 'Crea&#355;i o sub-rubric&#259;',
'icone_deconnecter' => 'Deconecta&#355;i-v&#259;',
'icone_discussions' => 'Discu&#355;ii',
'icone_doc_rubrique' => 'Documentele rubricilor',
'icone_ecrire_article' => 'Scrie&#355;i un nou articol',
'icone_edition_site' => 'Edita&#355;i',
'icone_forum_administrateur' => 'Forum-ul administratorilor',
'icone_forum_suivi' => 'Urm&#259;rirea forum-urilor',
'icone_gestion_langues' => 'Gestiunea limbilor',
'icone_informations_personnelles' => 'Informa&#355;ii personale',
'icone_interface_complet' => 'interfa&#355;a complet&#259;',
'icone_interface_simple' => 'interfa&#355;a simplificat&#259;',
'icone_maintenance_site' => '&Icirc;ntre&#355;inerea site-ului',
'icone_messagerie_personnelle' => 'Mesageria personal&#259;',
'icone_mots_cles' => 'Cuvinte-cheie',
'icone_nouvelle_breve' => 'Scrie&#355;i o nou&#259; &#351;tire',
'icone_repartition_actuelle' => 'Afi&#351;a&#355;i reparti&#355;ia curent&#259;',
'icone_repartition_debut' => 'Afi&#351;a&#355;i reparti&#355;ia de la &icirc;nceput',
'icone_repartition_visites' => 'Reparti&#355;ia vizitelor',
'icone_rubriques' => 'Rubrici',
'icone_sauver_site' => 'Salvarea site-ului',
'icone_site_entier' => 'Tot site-ul',
'icone_sites_references' => 'Site-uri referen&#355;iate',
'icone_statistiques' => 'Statisticile site-ului',
'icone_statistiques_visites' => 'Statistici',
'icone_suivi_activite' => 'Urm&#259;ri&#355;i activitatea site-ului',
'icone_suivi_actualite' => 'Evolu&#355;ia site-ului',
'icone_suivi_forums' => 'Administrare forumuri',
'icone_suivi_pettions' => 'Urm&#259;ri&#355;i/gestiona&#355;i peti&#355;iile',
'icone_suivi_revisions' => 'Modific&#259;ri ale articolelor',
'icone_supprimer_document' => 'Suprima&#355;i acest document',
'icone_supprimer_image' => 'Suprima&#355;i aceast&#259; imagine',
'icone_supprimer_message' => 'Suprima&#355;i acest mesaj',
'icone_tous_articles' => 'Toate articolele dvs.',
'icone_tous_auteur' => 'To&#355;i autorii',
'icone_valider_message' => 'Valida&#355;i acest mesaj',
'icone_visiter_site' => 'Vizita&#355;i',
'icone_voir_en_ligne' => 'Vede&#355;i &icirc;n direct',
'image_tourner_180' => 'Rota&#355;ie 180&deg;',
'image_tourner_droite' => 'Rota&#355;ie 90&deg; la dreapta',
'image_tourner_gauche' => 'Rota&#355;ie 90&deg; la st&acirc;nga',
'img_indisponible' => 'imagine nedisponibil&#259;',
'impossible' => 'imposibil',
'info_a_suivre' => 'DE URM&#258;RIT&nbsp;&raquo;',
'info_a_valider' => '[de validat]',
'info_acces_interdit' => 'Acces interzis',
'info_acces_refuse' => 'Acces refuzat',
'info_action' => 'Ac&#539;iune : @action@',
'info_administrer_rubriques' => 'Pute&#355;i administra aceast&#259; rubric&#259; &#351;i sub-rubricile ei',
'info_adresse_non_indiquee' => 'Nu a&#355;i indicat adresa de testat&nbsp; !',
'info_aide' => 'AJUTOR :',
'info_ajouter_mot' => 'Ad&#259;uga&#355;i acest cuv&acirc;nt',
'info_annonce' => 'ANUN&#354;',
'info_annonces_generales' => 'Anun&#355;uri generale&nbsp;:',
'info_article_propose' => 'Articol propus',
'info_article_publie' => 'Articol publicat',
'info_article_redaction' => 'Articol &icirc;n curs de redactare',
'info_article_refuse' => 'Articol refuzat',
'info_article_supprime' => 'Articol suprimat',
'info_articles' => 'Articole',
'info_articles_a_valider' => 'Articole pentru validare',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Articole propuse',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'autor(i)&nbsp;:',
'info_authentification_ftp' => 'Autentificare (prin FTP).',
'info_bloquer_lien' => 'bloca&#355;i aceast&#259; leg&#259;tur&#259;',
'info_breves_02' => '&#350;tiri',
'info_breves_2' => '&#351;tiri',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => '&#350;tiri de validat',
'info_connexion_refusee' => 'Conexiune refuzat&#259;',
'info_contact_developpeur' => 'V&#259; rug&#259;m s&#259; contacta&#355;i un dezvoltator.',
'info_contenance' => 'Acest site con&#355;ine&nbsp;:',
'info_contribution' => 'contribu&#355;ii la forum',
'info_copyright' => '@spip@ este un program liber distribuit @lien_gpl@.',
'info_copyright_doc' => 'Pentru mai multe informa&#355;ii, vizita&#355;i site-ul <a href="@spipnet@">http://www.spip.net/ro</a>.',
'info_copyright_gpl' => 'sub licen&#355;&#259; GPL',
'info_cours_edition' => 'Articolele dumneavoastr&#259; &icirc;n curs de redactare',
'info_creer_repertoire' => 'V&#259; rug&#259;m s&#259; crea&#355;i un fi&#537;ier sau un director numit&nbsp;:',
'info_creer_repertoire_2' => 'sub directorul <b>@repertoire@</b>, apoi&nbsp;:',
'info_creer_vignette' => 'crearea vini&eacute;tei &icirc;n mod automat ',
'info_deplier' => 'Desface&#355;i',
'info_descriptif_nombre' => 'descriere(i)&nbsp;:',
'info_description' => 'Descriere&nbsp;:',
'info_description_2' => 'Descriere&nbsp;:',
'info_dimension' => 'Dimensiuni&nbsp;:',
'info_document' => 'Document',
'info_document_indisponible' => 'Acest document nu este disponibil',
'info_documents' => 'Documente',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP permite schimbul de mesaje &#351;i constituirea de forumuri de discu&#355;ie
 private &icirc;ntre participan&#355;ii site-ului. Pute&#355;i activa sau
 dezactiva aceast&#259; func&#355;ionalitate.',
'info_ecire_message_prive' => 'Scrie&#355;i un nou mesaj privat',
'info_email_invalide' => 'Adres&#259; invalid&#259; de email.',
'info_en_cours_validation' => 'Articolele dvs. &icirc;n curs de redactare',
'info_en_ligne' => '&Icirc;n acest moment &icirc;n linie&nbsp;:',
'info_envoyer_message_prive' => 'Trimite&#355;i un mesaj privat acestui autor',
'info_erreur_requete' => 'Eroare &icirc;n cererea :',
'info_erreur_squelette2' => 'Nici un schelet <b>@fichier@</b> nu este disponibil...',
'info_erreur_systeme' => 'Eroare sistem (errno @errsys@)',
'info_erreur_systeme2' => 'Discul este probabil plin sau baza de date este corupt&#259;.
 <font color=\'red\'>&Icirc;ncerca&#355;i s&#259; <a href=\'@script@\'>repara&#355;i baza de date</a>,
 sau contacta&#355;i-l pe furnizorul dumneavoastr&#259; de internet.</font>',
'info_fini' => 'Este gata !',
'info_format_image' => 'Formatele de imagini care pot fi folosite la crearea vini&eacute;telor&nbsp;: @gd_formats@.',
'info_format_non_defini' => 'format nedefinit',
'info_grand_ecran' => 'Ecran mare',
'info_image_aide' => 'AJUTOR',
'info_image_process_titre' => 'Metoda pentru elaborarea vinietelor',
'info_impossible_lire_page' => '<b>Eroare !</b> Imposibil de citit pagina <tt><html>@test_proxy@</html></tt> prin intermediul proxy-ului',
'info_inclusion_directe' => 'Includere direct&#259;&nbsp;:',
'info_inclusion_vignette' => 'Includerea vinietei&nbsp;:',
'info_installation_systeme_publication' => 'Instalarea sistemului de publicare...',
'info_installer_documents' => 'Pute&#355;i instala &icirc;n mod automat toate documentele con&#355;inute &icirc;n directorul @upload@.',
'info_installer_ftp' => 'Ca administrator, pute&#355;i s&#259; instala&#355;i (prin FTP) fi&#351;iere &icirc;n directorul @upload@ pentru ca mai apoi s&#259; le selec&#355;iona&#355;i direct aici.',
'info_installer_images' => 'Pute&#355;i instala imagini &icirc;n formatele JPEG, GIF &#351;i PNG.',
'info_installer_images_dossier' => 'Instala&#355;i imagini &icirc;n directorul @upload@ pentru a putea s&#259; le selec&#355;iona&#355;i aici.',
'info_installer_tous_documents' => 'Instala&#355;i toate documentele',
'info_interface_complete' => 'interfa&#355;a complet&#259;',
'info_interface_simple' => 'Interfa&#355;a simplificat&#259;',
'info_joindre_document_article' => 'Pute&#355;i s&#259; ata&#351;a&#355;i acestui articol documente de tipul',
'info_joindre_document_rubrique' => 'Pute&#355;i s&#259; ata&#351;a&#355;i acestei rubrici documente de tipul',
'info_joindre_documents_article' => 'Pute&#355;i s&#259; ata&#351;a&#355;i articolului dumneavoastr&#259; documente de tipul&nbsp;:',
'info_l_article' => 'articolul',
'info_la_breve' => '&#351;tirea',
'info_la_rubrique' => 'rubrica',
'info_langue_principale' => 'Limba principal&#259; a site-ului',
'info_largeur_vignette' => '@largeur_vignette@ &times; @hauteur_vignette@ pixeli',
'info_les_auteurs_1' => 'de @les_auteurs@',
'info_logo_format_interdit' => 'Doar vini&eacute;tele cu formatul @formats@ sunt autorizate.',
'info_logo_max_poids' => 'Vini&eacute;tele trebuie &icirc;n mod obligatoriu s&#259; fie mai mici de @maxi@ (acest fi&#351;ier are @actuel@).',
'info_logo_max_taille' => 'Vini&eacute;tele trebuie &icirc;n mod obligatoriu s&#259; fie mai mici de @maxi@ (acest fi&#351;ier are @actuel@).',
'info_mail_fournisseur' => 'dumneavoastr&#259;@furnizor.ro',
'info_message_2' => 'MESAJ',
'info_message_supprime' => 'MESAJ &#350;TERS',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Data public&#259;rii&nbsp;:',
'info_modification_parametres_securite' => 'modific&#259;ri ale parametrilor de securitate',
'info_mois_courant' => '&Icirc;n timpul lunii :',
'info_mot_cle_ajoute' => 'Cuv&acirc;ntul-cheie urm&#259;tor a fost ad&#259;ugat la',
'info_multi_herit' => 'Limba implicit&#259;',
'info_multi_langues_soulignees' => '<u>Limbile subliniate</u> beneficiaz&#259; de o traducere a tuturor textelor interfe&#355;ei. Dac&#259; ve&#355;i selec&#355;iona o astfel de limb&#259;, numeroase elemente ale site-ului public (date, formulare) vor fi traduse &icirc;n mod automat. Pentru limbile nesubliniate, aceste elemente vor apare &icirc;n limba principal&#259; a site-ului.',
'info_multilinguisme' => 'Multilingvism',
'info_nom_non_utilisateurs_connectes' => 'Numele dumneavoastr&#259; nu apare &icirc;n lista utilizatorilor conecta&#355;i.',
'info_nom_utilisateurs_connectes' => 'Numele dumneavoastr&#259; apare &icirc;n lista utilizatorilor conecta&#355;i.',
'info_nombre_en_ligne' => 'Acum &icirc;n linie&nbsp;:',
'info_non_resultat' => 'Nici un rezultat pentru "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'Nu pute&#355;i utiliza mesageria intern&#259; a acestui site.',
'info_nouveau_message' => 'AVE&#354;I UN NOU MESAJ',
'info_nouveaux_messages' => 'AVE&#354;I @total_messages@ MESAJE NOI',
'info_numero_abbreviation' => 'Nr&nbsp;',
'info_obligatoire' => 'Aceast&#259; informa&#355;ie este obligatorie',
'info_panne_site_syndique' => 'Site sidicalizat &icirc;n pan&#259;',
'info_pense_bete' => 'CIORN&#258;',
'info_petit_ecran' => 'Ecran mic',
'info_petition_close' => 'Peti&#355;ie &icirc;nchis&#259;',
'info_pixels' => 'pixeli',
'info_plusieurs_mots_trouves' => 'Mai multe cuvinte-cheie g&#259;site pentru "@cherche_mot@":',
'info_popularite_5' => 'popularitate&nbsp;:',
'info_portfolio' => 'Portofoliu',
'info_portfolio_automatique' => 'Portofoliu automatic&nbsp;:',
'info_premier_resultat' => '[@debut_limit@ primele rezultate din @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ primele rezultate din @total@]',
'info_probleme_grave' => 'problem&#259; de',
'info_propose_1' => '[@nom_site_spip@] Propune : @titre@',
'info_propose_2' => 'Articol propus
---------------',
'info_propose_3' => 'Articolul "@titre@" este propus pentru publicare.',
'info_propose_4' => 'Sunte&#355;i invitat s&#259; consulta&#355;i &#351;i s&#259; v&#259; exprima&#355;i opinia',
'info_propose_5' => '&nbsp;&icirc;n forum-ul care &icirc;i este anexat. Acesta este disponibil la adresa :',
'info_publie_01' => 'Articolul "@titre@" a fost validat de c&#259;tre @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] PUBLIC&#258; : @titre@',
'info_publie_2' => 'Articol publicat
--------------',
'info_rechercher' => 'C&#259;uta&#355;i',
'info_rechercher_02' => 'C&#259;uta&#355;i&nbsp;:',
'info_remplacer_vignette' => '&Icirc;nlocui&#355;i vini&eacute;ta implicit&#259; cu o vini&eacute;t&#259; personalizat&#259;&nbsp;:',
'info_retablir_lien' => 'restabili&#355;i aceast&#259; legatur&#259;',
'info_retirer_mot' => 'Retrage&#355;i acest cuv&acirc;nt',
'info_retirer_mots' => 'Retrage&#355;i toate cuvintele',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => 'f&#259;r&#259; titlu',
'info_selectionner_fichier' => 'Pute&#355;i selec&#355;iona un fi&#351;ier din directorul @upload@',
'info_selectionner_fichier_2' => 'Selec&#355;iona&#355;i un fi&#351;ier&nbsp;:',
'info_signature_supprimee' => 'Semn&#259;tur&#259; suprimat&#259;',
'info_signature_supprimee_erreur' => 'Eroare&nbsp;: acest cod de &#351;tergere nu corespunde nici unei semn&#259;turi',
'info_site_attente' => 'Site Web &icirc;n a&#351;teptarea valid&#259;rii',
'info_site_reference' => 'Site referen&#355;iat &icirc;n direct',
'info_site_refuse' => 'Site Web refuzat',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Referen&#355;iere site',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => '&nbsp;suprima&#355;i vinieta',
'info_symbole_bleu' => 'Simbolul <b>albastru</b> indic&#259; o <b>ciorn&#259;</b>: adic&#259; un mesaj pentru folosin&#355;a dumneavoastr&#259; personal&#259;.',
'info_symbole_jaune' => 'Simbolul <b>galben</b> indic&#259; un <b>anun&#355; c&#259;tre to&#355;i redactorii</b>&nbsp;: modificabil de c&#259;tre to&#355;i administratorii &#351;i vizibil pentru to&#355;i redactorii.',
'info_symbole_vert' => 'Simbolul <b>verde</b> indic&#259; un <b>mesaj schimbat cu ceilal&#355;i utilizatori</b> ai site-ului.',
'info_syndication' => 'sindicare&nbsp;:',
'info_syndication_articles' => 'articol(e)',
'info_telecharger' => '&Icirc;nc&#259;rca&#355;i de pe calculatorul dumneavoastr&#259;&nbsp;:',
'info_telecharger_nouveau_logo' => '&Icirc;nc&#259;rca&#355;i o nou&#259; vini&eacute;t&#259;&nbsp;:',
'info_telecharger_ordinateur' => '&Icirc;nc&#259;rca&#355;i de pe calculatorul dumneavoastr&#259;&nbsp;:',
'info_tous_resultats_enregistres' => '[toate rezultatele sunt &icirc;nregistrate]',
'info_tout_afficher' => 'Afi&#351;a&#355;i totul',
'info_travaux_texte' => 'Acest site nu a fost &icirc;nc&#259; configurat. Reveni&#355;i alt&#259; dat&#259;...',
'info_travaux_titre' => 'Site &icirc;n lucru',
'info_trop_resultat' => 'Prea multe rezultate pentru "@cherche_mot@" ; v&#259; rug&#259;m s&#259; mic&#351;ora&#355;i domeniul de c&#259;utare.',
'info_utilisation_messagerie_interne' => 'Utiliza&#355;i sistemul de mesagerie intern&#259; al site-ului.',
'info_valider_lien' => '&nbsp;valida&#355;i aceast&#259; leg&#259;tur&#259;',
'info_verifier_image' => ', v&#259; rug&#259;m s&#259; verifica&#355;i c&#259; imaginile au fost transferate corect.',
'info_vignette_defaut' => 'Viniet&#259; implicit&#259;',
'info_vignette_personnalisee' => 'Viniet&#259; personalizat&#259;',
'info_visite' => 'vizit&#259; :',
'info_visites' => 'vizite :',
'info_vos_rendez_vous' => 'Urm&#259;toarele dumneavoastr&#259; &icirc;nt&acirc;lniri',
'info_zoom' => 'm&#259;rire',
'infos_vos_pense_bete' => 'Ciornele dumneavoastr&#259;',
'item_breve_proposee' => '&#350;tire propus&#259;',

// L
'lien_afficher_icones_seuls' => 'Afi&#351;a&#355;i doar iconi&#355;e',
'lien_afficher_texte_icones' => 'Afi&#351;a&#355;i iconi&#355;e &#351;i text',
'lien_afficher_texte_seul' => 'Afi&#351;a&#355;i doar text',
'lien_liberer' => 'elibera&#355;i',
'lien_liberer_tous' => 'elibera&#355;i aceste articole',
'lien_nouvea_pense_bete' => 'CIORN&#258; NOU&#258;',
'lien_nouveau_message' => 'MESAJ NOU',
'lien_nouvelle_annonce' => 'ANUN&#354; NOU',
'lien_petitions' => 'PETI&#354;IE',
'lien_popularite' => 'popularitate&nbsp;: @popularite@%',
'lien_racine_site' => 'R&#258;D&#258;CINA SITE-ULUI',
'lien_reessayer' => 're&icirc;ncerca&#355;i',
'lien_repondre_message' => 'R&#259;spunde&#355;i la acest mesaj',
'lien_supprimer' => '&#351;terge&#355;i',
'lien_tout_afficher' => 'Afi&#351;a&#355;i totul',
'lien_visite_site' => 'vizita&#355;i acest site',
'lien_visites' => '@visites@&nbsp;vizite',
'lien_voir_auteur' => 'Vede&#355;i acest autor',
'ligne' => 'Linie',
'login' => 'Conexiune',
'login_acces_prive' => 'acces la sec&#355;iunea privat&#259;',
'login_autre_identifiant' => 'conectare sub un alt cont',
'login_cookie_accepte' => 'V&#259; rug&#259;m s&#259; regla&#355;i navigatorul dumneavoastr&#259; de web &icirc;n a&#351;a fel &icirc;nc&acirc;t s&#259; accepte cookies (cel pu&#355;in pentru acest site).',
'login_cookie_oblige' => 'Pentru a fi identificat de o manier&#259; sigur&#259; pe acest site va trebui s&#259; accepta&#355;i cookies.',
'login_deconnexion_ok' => 'Deconectare OK.',
'login_erreur_pass' => 'Eroare de parol&#259;.',
'login_espace_prive' => 'spa&#355;iu privat',
'login_identifiant_inconnu' => 'identificatorul &laquo; @login@ &raquo; este necunoscut.',
'login_login' => 'Login :',
'login_login2' => 'Login (identificator de conectare la site)&nbsp;:',
'login_login_pass_incorrect' => '(Login sau parol&#259; incorect&#259;.)',
'login_motpasseoublie' => 'parol&#259;&nbsp;uitat&#259;&nbsp;?',
'login_non_securise' => 'Aten&#355;ie, acest formular nu este securizat.
    Dac&#259; nu dori&#355;i ca parola dumneavoastr&#259; s&#259; poat&#259; fi interceptat&#259; pe net, v&#259; rug&#259;m s&#259; activa&#355;i Javascript
    pentru navigatorul dumneavoastr&#259; de web &#351;i',
'login_nouvelle_tentative' => 'O nou&#259; &icirc;ncercare',
'login_par_ici' => 'Sunte&#355;i &icirc;nregistrat... v&#259; rugam s&#259; veni&#355;i pe aici...',
'login_pass2' => 'Parol&#259;&nbsp;:',
'login_preferez_refuser' => '<b>Dac&#259; prefera&#355;i s&#259; refuza&#355;i cookies</b>, exist&#259; o alt&#259; metod&#259; de conectare (mai pu&#355;in sigur&#259;) la dispozi&#355;ia dumneavoastr&#259;&nbsp;:',
'login_recharger' => 're-&icirc;nc&#259;rca&#355;i aceast&#259; pagin&#259;',
'login_rester_identifie' => 'R&#259;m&acirc;ne&#355;i autentificat pentru c&acirc;teva zile',
'login_retour_public' => '&Icirc;napoi la site-ul public',
'login_retour_site' => '&Icirc;napoi la site-ul public',
'login_retoursitepublic' => '&icirc;napoi&nbsp;la&nbsp;site-ul&nbsp;public',
'login_sans_cookiie' => 'Identificare f&#259;r&#259; cookie',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => '&icirc;nscrie&#355;i-v&#259;',
'login_test_navigateur' => 'test de navigator/reconectare',
'login_verifiez_navigateur' => '(Verifica&#355;i totu&#351;i c&#259; navigatorul de web nu a memorat parola dumneavoastr&#259;...)',

// M
'masquer_colonne' => 'Masca&#355;i aceast&#259; coloan&#259;',
'masquer_trad' => 'masca&#355;i traducerile',
'module_fichiers_langues' => 'Fi&#351;iere de limb&#259;',

// N
'navigateur_pas_redirige' => 'Dac&#259; navigatorul dumneavoastr&#259; nu este redirijat &icirc;n mod automatic, face&#355;i click aici pentru a continua.',
'numero' => 'Num&#259;r',

// O
'occurence' => 'Ocuren&#355;&#259;',
'onglet_affacer_base' => '&#350;terge&#355;i baza',
'onglet_auteur' => 'Autorul',
'onglet_contenu_site' => 'Con&#355;inutul site-ului',
'onglet_evolution_visite_mod' => 'Evolu&#355;ie',
'onglet_fonctions_avances' => 'Func&#355;ii avansate',
'onglet_informations_personnelles' => 'Informa&#355;ii personale',
'onglet_interactivite' => 'Interactivitate',
'onglet_messagerie' => 'Mesagerie',
'onglet_messages_internes' => 'Mesaje interne',
'onglet_messages_publics' => 'Mesaje publice',
'onglet_messages_vide' => 'Mesaje f&#259;r&#259; text',
'onglet_origine_visites' => 'Originea vizitelor',
'onglet_repartition_debut' => 'de la &icirc;nceput',
'onglet_repartition_lang' => 'Reparti&#355;ia pe limbi',
'onglet_repartition_rubrique' => 'Reparti&#355;ia pe rubrici',
'onglet_save_restaur_base' => 'Salva&#355;i/restaura&#355;i baza de date',
'onglet_vider_cache' => 'Goli&#355;i memoria tampon',
'ortho_trop_de_fautes2' => '&Icirc;ncepe&#355;i prin a corecta erorile cele mai evidente &#351;i re-&icirc;ncerca&#355;i dup&#259; aceea.',

// P
'pass_choix_pass' => 'V&#259; rug&#259;m s&#259; alege&#355;i noua dumneavoastr&#259; parol&#259; :',
'pass_erreur' => 'Eroare',
'pass_erreur_acces_refuse' => '<b>Eroare :</b> nu mai ave&#355;i acces la acest site.',
'pass_erreur_code_inconnu' => '<b>Eroare :</b> acest cod nu corespunde nici unui vizitator av&acirc;nd acces la site.',
'pass_erreur_non_enregistre' => '<b>Eroare :</b> adresa <tt>@email_oubli@</tt> nu este &icirc;nregistrat&#259; pe acest site.',
'pass_erreur_non_valide' => '<b>Eroare :</b> acest email <tt>@email_oubli@</tt> nu este valabil !',
'pass_erreur_probleme_technique' => '<b>Eroare :</b> din cauza unei probleme tehnice, email-ul nu a putut fi trimis.',
'pass_espace_prive_bla' => 'Spa&#355;iul privat al acestui site este deschis
  vizitatorilor dup&#259; &icirc;nscriere. Odat&#259; &icirc;nregistrat
  ve&#355;i putea consulta articolele &icirc;n curs de editare,
  ve&#355;i putea propune articole &#351;i ve&#355;i putea participa la toate forum-urile.',
'pass_forum_bla' => 'A&#355;i cerut s&#259; interveni&#355;i pe un forum
  rezervat vizitatorilor &icirc;nregistra&#355;i.',
'pass_indiquez_cidessous' => 'V&#259; rug&#259;m s&#259; indica&#539;i adresa de email cu care v-a&#355;i &icirc;nregistrat &icirc;n trecut.
Ve&#355;i primi un email care v&#259; va indica pa&#351;ii necesari recuper&#259;rii accesului la site.',
'pass_mail_passcookie' => '(acesta este un mesaj automatic)
Pentru a reg&#259;si accesul la site-ul
@nom_site_spip@ (@adresse_site@)

V&#259; rug&#259;m s&#259; vizita&#355;i adresa urm&#259;toare :

    @sendcookie@

Ve&#355;i putea dup&#259; aceea alege o nou&#259; parol&#259; &#351;i ve&#355;i putea s&#259; v&#259; reconecta&#355;i la site.

',
'pass_mot_oublie' => 'Parol&#259; uitat&#259;',
'pass_nouveau_enregistre' => 'Noua dumneavoastr&#259; parol&#259; a fost &icirc;nregistrat&#259;.',
'pass_nouveau_pass' => 'Parol&#259; nou&#259;',
'pass_ok' => 'OK',
'pass_oubli_mot' => 'Parol&#259; uitat&#259;',
'pass_quitter_fenetre' => 'P&#259;r&#259;si&#355;i aceast&#259; fereastr&#259;',
'pass_rappel_login' => 'Aten&#355;ie : identificatorul dumneavoastr&#259; (login) este &laquo; @login@ &raquo;.',
'pass_recevoir_mail' => 'Ve&#355;i primi &icirc;n cur&acirc;nd un email care v&#259; va indica cum pute&#355;i s&#259; recupera&#355;i accesul la site.',
'pass_retour_public' => '&Icirc;ntoarce&#355;i-v&#259; la site-ul public',
'pass_rien_a_faire_ici' => 'Nimic de f&#259;cut aici.',
'pass_vousinscrire' => '&Icirc;nscrie&#355;i-v&#259; pe acest site',
'precedent' => 'precedent',
'previsualisation' => 'pre-vizualizare',
'previsualiser' => 'Pre-vizualizare',

// R
'retour' => 'Retur',

// S
'spip_conforme_dtd' => 'SPIP consider&#259; acest document ca fiind conform cu DOCTYPE-ul s&#259;u: ',
'squelette' => 'schelet',
'squelette_inclus_ligne' => 'schelet inclus, linia',
'squelette_ligne' => 'schelet, linia',
'stats_visites_et_popularite' => '@visites@ vizite&nbsp;; popularitate&nbsp;: @popularite@',
'suivant' => 'urm&#259;torul',

// T
'taille_ko' => '@taille@&nbsp;ko',
'taille_mo' => '@taille@&nbsp;MB',
'taille_octets' => '@taille@&nbsp;octe&#355;i',
'texte_actualite_site_1' => 'C&acirc;nd ve&#355;i fi familiarizat cu interfa&#355;a, pute&#355;i face click pe &laquo;',
'texte_actualite_site_2' => 'interfa&#355;a complet&#259;',
'texte_actualite_site_3' => '&raquo; pentru a v&#259; deschide mai multe posibilit&#259;&#355;i.',
'texte_creation_automatique_vignette' => 'Crearea automatic&#259; de viniete de pre-vizualizare este activat&#259; pe acest site. Dac&#259; ve&#355;i instala imagini cu ajutorul acestui formular &icirc;n formatele @gd_formats@, ele vor fi acompaniate de o viniet&#259; de o talie maximal&#259; de @taille_preview@&nbsp;pixeli.',
'texte_documents_associes' => 'Documentele urm&#259;toare sunt asociate articolului,
   dar nu au fost inserate &icirc;n mod direct. &Icirc;n func&#355;ie de punerea &icirc;n pagin&#259; a site-ului public,
  acestea ar putea ap&#259;rea ca documente ata&#351;ate.',
'texte_erreur_mise_niveau_base' => 'Eroare la nivelul bazei de date &icirc;n timpul actualiz&#259;rii.
  Imaginea <b>@fichier@</b> nu a trecut (articolul @id_article@).
  Nota&#355;i aceast&#259; referin&#355;&#259;, re-&icirc;ncerca&#355;i o actualizare &#351;i verifica&#355;i dac&#259; imaginile apar
  &icirc;n articole.',
'texte_erreur_visiteur' => 'A&#355;i &icirc;ncercat s&#259; accesa&#355;i sec&#355;iunea protejat&#259; cu un nume de utilizator f&#259;r&#259; drepturi.',
'texte_inc_auth_1' => 'V-a&#355;i identificat cu
  login <b>@auth_login@</b>, dar acesta nu (mai) exist&#259; &icirc;n baza de date.
  &Icirc;ncerca&#355;i s&#259;',
'texte_inc_auth_2' => 'v&#259; reconecta&#355;i',
'texte_inc_auth_3' => ', dup&#259; ce, eventual, a&#355;i p&#259;r&#259;sit &#351;i redemarat navigatorul de web.',
'texte_inc_config' => 'Modific&#259;rile efectuate &icirc;n aceste pagini au influen&#355;&#259; direct&#259; asupra func&#355;ion&#259;rii site-ului. V&#259; recomand&#259;m s&#259; nu interveni&#355;i at&acirc;t timp c&acirc;t nu sunte&#355;i familiarizat cu func&#355;ionarea sistemului SPIP. <br /><br /><b>&Icirc;n
 general, este recomandat s&#259; l&#259;sa&#355;i aceste pagini &icirc;n sarcina webmaster-ului principal al acestui site.</b>',
'texte_inc_meta_1' => 'Sistemul a &icirc;nt&acirc;lnit o eroare la scrierea fi&#351;ierului <code>@fichier@</code>. V&#259; rugam ca, &icirc;n calitate de administrator al acestui site,',
'texte_inc_meta_2' => 's&#259; verifica&#355;i drepturile de scriere',
'texte_inc_meta_3' => '&icirc;n directorul <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => '&icirc;n curs de redactare',
'texte_statut_poubelle' => 'la co&#351;ul de gunoi',
'texte_statut_propose_evaluation' => 'propus pentru evaluare',
'texte_statut_publie' => 'publicat &icirc;n direct',
'texte_statut_refuse' => 'refuzat',
'titre_ajouter_mot_cle' => 'AD&#258;UGA&#354;I UN CUV&Acirc;NT-CHEIE :',
'titre_breve_proposee' => '&#350;tire propus&#259;',
'titre_breve_publiee' => '&#350;tire publicat&#259;',
'titre_breve_refusee' => '&#350;tire refuzat&#259;',
'titre_cadre_raccourcis' => 'SCURT&#258;TURI :',
'titre_changer_couleur_interface' => 'Schimb&#259; culoarea interfe&#355;ei',
'titre_forum' => 'Forum',
'titre_image_admin_article' => 'Pute&#355;i administra acest articol',
'titre_image_administrateur' => 'Administrator',
'titre_image_aide' => 'Ajutor despre acest element',
'titre_image_auteur_supprime' => 'Autor suprimat',
'titre_image_redacteur' => 'Redactor f&#259;r&#259; acces',
'titre_image_redacteur_02' => 'Redactor',
'titre_image_visiteur' => 'Vizitator',
'titre_joindre_document' => 'ATA&#350;A&#354;I DOCUMENT',
'titre_liens_entrants' => 'Leg&#259;turi &icirc;n intrare',
'titre_mots_cles' => 'CUVINTE-CHEIE',
'titre_probleme_technique' => 'Aten&#355;ie&nbsp;: o problem&#259; tehnic&#259; (server SQL) &icirc;mpiedic&#259; accesul la aceast&#259; parte a site-ului. V&#259; mul&#355;umim pentru &icirc;n&#355;elegere.',
'titre_publier_document' => 'PUBLIC&#258; UN DOCUMENT &Icirc;N ACEAST&#258; RUBRIC&#258;',
'titre_signatures_attente' => 'Semn&#259;turi &icirc;n a&#351;teptarea valid&#259;rii',
'titre_signatures_confirmees' => 'Semn&#259;turi confirmate',
'titre_statistiques' => 'Statisticile site-ului',
'titre_titre_document' => 'Titlul documentului:',
'todo' => 'de f&#259;cut',
'trad_reference' => '(articol de referin&#355;&#259;)',

// Z
'zbug_balise_b_aval' => '&nbsp;: element B &icirc;nainte',
'zbug_balise_inexistante' => 'eroare @from@: baliza #@balise@ nu exist&#259;', # MODIF
'zbug_balise_sans_argument' => 'Argument lips&#259; &icirc;n baliza @balise@',
'zbug_boucle' => 'bucl&#259;',
'zbug_boucle_recursive_undef' => 'Bucl&#259; recursiv&#259; nedefinit&#259;: @nom@',
'zbug_calcul' => 'calcul',
'zbug_champ_hors_boucle' => 'C&acirc;mp @champ@ &icirc;n afara buclei',
'zbug_champ_hors_motif' => 'C&acirc;mp @champ@ &icirc;n afara contextului buclei @motif@',
'zbug_code' => 'cod',
'zbug_critere_inconnu' => 'Criteriu necunoscut @critere@',
'zbug_distant_interdit' => 'Extern interzis',
'zbug_doublon_table_sans_cle_primaire' => 'Dubluri &icirc;ntr-o tabel&#259; f&#259;r&#259; cheie primar&#259; atomic&#259;',
'zbug_doublon_table_sans_index' => 'Dubluri &icirc;ntr-o tabel&#259; f&#259;r&#259; index',
'zbug_erreur_boucle_double' => 'Bucla @id@: defini&#355;ie dubl&#259;',
'zbug_erreur_boucle_fermant' => 'Bucla @id@: tag-ul de &icirc;nchidere lipse&#351;te',
'zbug_erreur_boucle_syntaxe' => 'Sintax&#259; incorect&#259; pentru bucla @id@',
'zbug_erreur_compilation' => 'Eroare de compilare',
'zbug_erreur_execution_page' => 'Eroare de execu&#355;ie',
'zbug_erreur_filtre' => 'Filtru @filtre@ nedefinit',
'zbug_erreur_meme_parent' => 'Criteriul {meme_parent} nu se aplic&#259; dec&acirc;t buclelor (FORUMS) sau (RUBRIQUES)',
'zbug_erreur_squelette' => 'Eroare/Erori &icirc;n schelet',
'zbug_hors_compilation' => 'F&#259;r&#259; compilare',
'zbug_info_erreur_squelette' => 'Eroare pe site',
'zbug_inversion_ordre_inexistant' => 'Inversie de ordin necunoscut',
'zbug_pagination_sans_critere' => 'Baliza #PAGINATION f&#259;r criteriu {pagination} sau folosit &icirc;ntr-o bucl&#259; recursiv&#259;',
'zbug_parametres_inclus_incorrects' => 'Parametru de includere incorect: @param@', # MODIF
'zbug_profile' => 'Timp de calcul&nbsp;: @time@',
'zbug_resultat' => 'rezultat',
'zbug_serveur_indefini' => 'Server SQL nedefinit',
'zbug_statistiques' => 'Statisticile cererilor SQL clasate dup&#259; durat&#259;',
'zbug_table_inconnue' => 'Tabela SQL &laquo; @table@ &raquo; necunoscut&#259;',
'zxml_connus_attributs' => 'atribute cunoscute',
'zxml_de' => 'de',
'zxml_inconnu_attribut' => 'atribut necunoscut',
'zxml_inconnu_balise' => 'baliz&#259; (tag) necunoscut&#259;',
'zxml_inconnu_entite' => 'entitate necunoscut&#259;',
'zxml_inconnu_id' => 'ID necunoscut',
'zxml_mais_de' => 'dar de',
'zxml_non_conforme' => 'nu este conform cu motivul',
'zxml_non_fils' => 'nu este un fiu al',
'zxml_nonvide_balise' => 'baliz&#259; (tag) ne-vid&#259;',
'zxml_obligatoire_attribut' => 'atribut obligatoriu dar absent din',
'zxml_succession_fils_incorrecte' => 'succesiune incorect&#259; de fii',
'zxml_survoler' => 'plana&#355;i pentru a vedea corect',
'zxml_valeur_attribut' => 'valoarea atributului',
'zxml_vide_balise' => 'baliz&#259; (tag) vid&#259;',
'zxml_vu' => 'v&#259;zut &icirc;nainte'
);

?>
